@@ -30,6 +30,12 @@ _SPIRV_OP_INTERNAL(ComplexFDivINTEL, internal::ComplexFDivINTEL)
 _SPIRV_OP_INTERNAL(MaskedGatherINTEL, internal::OpMaskedGatherINTEL)
 _SPIRV_OP_INTERNAL(MaskedScatterINTEL, internal::OpMaskedScatterINTEL)
 _SPIRV_OP_INTERNAL(RoundFToTF32INTEL, internal::RoundFToTF32INTEL)
+_SPIRV_OP_INTERNAL(TaskSequenceAsyncINTEL, internal::OpTaskSequenceAsyncINTEL)
+_SPIRV_OP_INTERNAL(TaskSequenceCreateINTEL, internal::OpTaskSequenceCreateINTEL)
+_SPIRV_OP_INTERNAL(TaskSequenceGetINTEL, internal::OpTaskSequenceGetINTEL)
+_SPIRV_OP_INTERNAL(TaskSequenceReleaseINTEL,
+                   internal::OpTaskSequenceReleaseINTEL)
+_SPIRV_OP_INTERNAL(TypeTaskSequenceINTEL, internal::OpTypeTaskSequenceINTEL)
 _SPIRV_OP_INTERNAL(ConvertHandleToImageINTEL,
                    internal::ConvertHandleToImageINTEL)
 _SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
